# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: colav_proto/controllerFeedback.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$colav_proto/controllerFeedback.proto\x12\x05\x63olav\"\xe4\x03\n\x12\x43ontrollerFeedback\x12\x13\n\x0bmission_tag\x18\x01 \x02(\t\x12\x11\n\tagent_tag\x18\x02 \x02(\t\x12>\n\tctrl_mode\x18\x03 \x02(\x0e\x32\".colav.ControllerFeedback.CTRLMode:\x07UNKNOWN\x12I\n\x0b\x63trl_status\x18\x04 \x02(\x0e\x32$.colav.ControllerFeedback.CTRLStatus:\x0eUNKNOWN_STATUS\x12\x35\n\x08\x63trl_cmd\x18\x05 \x02(\x0b\x32#.colav.ControllerFeedback.CmdVelYaw\x12\x11\n\ttimestamp\x18\x06 \x02(\t\x1a/\n\tCmdVelYaw\x12\x10\n\x08velocity\x18\x01 \x02(\x02\x12\x10\n\x08yaw_rate\x18\x02 \x02(\x02\"Y\n\x08\x43TRLMode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x43RUISE\x10\x01\x12\t\n\x05T2LOS\x10\x02\x12\x0b\n\x07T2Theta\x10\x03\x12\x06\n\x02\x46\x42\x10\x04\x12\x14\n\x10WAYPOINT_REACHED\x10\x05\"E\n\nCTRLStatus\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\x12\t\n\x05\x45RROR\x10\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'colav_proto.controllerFeedback_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CONTROLLERFEEDBACK']._serialized_start=48
  _globals['_CONTROLLERFEEDBACK']._serialized_end=532
  _globals['_CONTROLLERFEEDBACK_CMDVELYAW']._serialized_start=323
  _globals['_CONTROLLERFEEDBACK_CMDVELYAW']._serialized_end=370
  _globals['_CONTROLLERFEEDBACK_CTRLMODE']._serialized_start=372
  _globals['_CONTROLLERFEEDBACK_CTRLMODE']._serialized_end=461
  _globals['_CONTROLLERFEEDBACK_CTRLSTATUS']._serialized_start=463
  _globals['_CONTROLLERFEEDBACK_CTRLSTATUS']._serialized_end=532
# @@protoc_insertion_point(module_scope)
