# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: colav_proto/agentUpdate.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63olav_proto/agentUpdate.proto\x12\x05\x63olav\"\xba\x03\n\x0b\x41gentUpdate\x12\x13\n\x0bmission_tag\x18\x01 \x02(\t\x12\x11\n\tagent_tag\x18\x02 \x02(\t\x12\'\n\x05state\x18\x03 \x02(\x0b\x32\x18.colav.AgentUpdate.State\x12\x11\n\ttimestamp\x18\x04 \x02(\t\x1a\xdc\x01\n\x04Pose\x12\x32\n\x08position\x18\x01 \x02(\x0b\x32 .colav.AgentUpdate.Pose.Position\x12\x38\n\x0borientation\x18\x02 \x02(\x0b\x32#.colav.AgentUpdate.Pose.Orientation\x1a+\n\x08Position\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x02(\x02\x1a\x39\n\x0bOrientation\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\x12\t\n\x01z\x18\x03 \x02(\x02\x12\t\n\x01w\x18\x04 \x02(\x02\x1ah\n\x05State\x12%\n\x04pose\x18\x01 \x02(\x0b\x32\x17.colav.AgentUpdate.Pose\x12\x10\n\x08velocity\x18\x02 \x02(\x02\x12\x10\n\x08yaw_rate\x18\x03 \x02(\x02\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x04 \x02(\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'colav_proto.agentUpdate_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_AGENTUPDATE']._serialized_start=41
  _globals['_AGENTUPDATE']._serialized_end=483
  _globals['_AGENTUPDATE_POSE']._serialized_start=157
  _globals['_AGENTUPDATE_POSE']._serialized_end=377
  _globals['_AGENTUPDATE_POSE_POSITION']._serialized_start=275
  _globals['_AGENTUPDATE_POSE_POSITION']._serialized_end=318
  _globals['_AGENTUPDATE_POSE_ORIENTATION']._serialized_start=320
  _globals['_AGENTUPDATE_POSE_ORIENTATION']._serialized_end=377
  _globals['_AGENTUPDATE_STATE']._serialized_start=379
  _globals['_AGENTUPDATE_STATE']._serialized_end=483
# @@protoc_insertion_point(module_scope)
